Module: Google::Cloud::Translate::V2
- Defined in:
- lib/google/cloud/translate/v2.rb,
lib/google/cloud/translate/v2/api.rb,
lib/google/cloud/translate/v2/service.rb,
lib/google/cloud/translate/v2/version.rb,
lib/google/cloud/translate/v2/language.rb,
lib/google/cloud/translate/v2/detection.rb,
lib/google/cloud/translate/v2/credentials.rb,
lib/google/cloud/translate/v2/translation.rb
Overview
Google Cloud Translation API
Google Cloud Translation API provides a simple, programmatic interface for translating an arbitrary string into any supported language. It is highly responsive, so websites and applications can integrate with Translation API for fast, dynamic translation of source text. Language detection is also available in cases where the source language is unknown.
Translation API supports more than one hundred different languages, from Afrikaans to Zulu. Used in combination, this enables translation between thousands of language pairs. Also, you can send in HTML and receive HTML with translated text back. You don't need to extract your source text or reassemble the translated content.
Defined Under Namespace
Classes: Api, Credentials, Detection, Language, Translation
Constant Summary collapse
- VERSION =
"1.2.0".freeze
Class Method Summary collapse
-
.new(project_id: nil, credentials: nil, key: nil, scope: nil, retries: nil, timeout: nil, endpoint: nil, enable_self_signed_jwt: nil) ⇒ Google::Cloud::Translate::V2::Api
Creates a new object for connecting to Cloud Translation API.
Class Method Details
.new(project_id: nil, credentials: nil, key: nil, scope: nil, retries: nil, timeout: nil, endpoint: nil, enable_self_signed_jwt: nil) ⇒ Google::Cloud::Translate::V2::Api
Creates a new object for connecting to Cloud Translation API. Each call creates a new connection.
Like other Cloud Platform services, Google Cloud Translation API supports authentication using a project ID and OAuth 2.0 credentials. In addition, it supports authentication using a public API access key. (If both the API key and the project and OAuth 2.0 credentials are provided, the API key will be used.) Instructions and configuration options are covered in the Authentication Guide.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/google/cloud/translate/v2.rb', line 103 def self.new project_id: nil, credentials: nil, key: nil, scope: nil, retries: nil, timeout: nil, endpoint: nil, enable_self_signed_jwt: nil project_id ||= default_project_id configuration = translation_config key ||= configuration&.key || ENV["TRANSLATE_KEY"] || ENV["GOOGLE_CLOUD_KEY"] retries ||= configuration&.retries timeout ||= configuration&.timeout endpoint ||= configuration&.endpoint if key return Google::Cloud::Translate::V2::Api.new( Google::Cloud::Translate::V2::Service.new( project_id.to_s, nil, retries: retries, timeout: timeout, key: key, host: endpoint ) ) end scope ||= configuration&.scope if enable_self_signed_jwt.nil? # Use self-signed JWT if the endpoint is unchanged from default (nil or default host). # This logic is adapted from gapic-generator-ruby templates, # simplified here since the default host is known to be global. enable_self_signed_jwt = endpoint.nil? || endpoint == Service::API_HOST end credentials ||= default_credentials scope: scope, enable_self_signed_jwt: enable_self_signed_jwt unless credentials.is_a? Google::Auth::Credentials credentials = Google::Cloud::Translate::V2::Credentials.new credentials, { scope: scope, enable_self_signed_jwt: enable_self_signed_jwt } end project_id = resolve_project_id project_id, credentials raise ArgumentError, "project_id is missing" if project_id.empty? Google::Cloud::Translate::V2::Api.new( Google::Cloud::Translate::V2::Service.new( project_id, credentials, retries: retries, timeout: timeout, host: endpoint ) ) end |